@@ -130,7 +130,7 @@ class Deformation_Spline:
         # subtract off the linear component.
         phi0, phi1 = phi[:1], phi[-1:]  # These are shape (1,N)
         phi_lin = phi0 + (phi1-phi0)*self._t
-        self._beta, residues, rank, s = np.linalg.lstsq(self._X, phi-phi_lin)
+        self._beta, residues, rank, s = np.linalg.lstsq(self._X, phi - phi_lin, rcond=-1)
 
         # save the points for future use.
         self.phi = np.asanyarray(phi)  # shape (n,N)
@@ -300,7 +300,7 @@ class Deformation_Spline:
         # fit to the spline
         phi_lin = phi[:1] + (phi[-1:]-phi[:1])*self._t
         phi -= phi_lin
-        self._beta, residues, rank, s = np.linalg.lstsq(self._X, phi)
+        self._beta, residues, rank, s = np.linalg.lstsq(self._X, phi, rcond=-1)
         phi = np.sum(self._beta[np.newaxis,:,:]*self._X[:,:,np.newaxis], axis=1)
         phi += phi_lin
         self.phi = phi
@@ -758,7 +758,7 @@ class SplinePath:
             xmin = optimize.fmin(V_lin, 0.0, args=(pts[0], dpts[0], V),
                                  xtol=1e-6, disp=0)[0]
             if xmin > 0.0: xmin = 0.0
-            nx = np.ceil(abs(xmin)-.5) + 1
+            nx = int(np.ceil(abs(xmin)-.5)) + 1
             x = np.linspace(xmin, 0, nx)[:, np.newaxis]
             pt_ext = pts[0] + x*dpts[0]
             pts = np.append(pt_ext, pts[1:], axis=0)
@@ -766,7 +766,7 @@ class SplinePath:
             xmin = optimize.fmin(V_lin, 0.0, args=(pts[-1], dpts[-1], V),
                                  xtol=1e-6, disp=0)[0]
             if xmin < 0.0: xmin = 0.0
-            nx = np.ceil(abs(xmin)-.5) + 1
+            nx = int(np.ceil(abs(xmin)-.5)) + 1
             x = np.linspace(xmin, 0, nx)[::-1, np.newaxis]
             pt_ext = pts[-1] + x*dpts[-1]
             pts = np.append(pts[:-1], pt_ext, axis=0)
